aboutsummaryrefslogtreecommitdiffstats
path: root/actionview/lib
diff options
context:
space:
mode:
authorTimm <kaspth@gmail.com>2014-05-24 00:03:48 +0200
committerTimm <kaspth@gmail.com>2014-06-16 21:04:24 +0200
commitd4cd7e2a44b2c19df31f7cb0ce03b957f3a359af (patch)
treee6e46e9c9c631609e9a950cb76a90df24db78bee /actionview/lib
parent33c8bfce0c81ee133dc62d56a727182e44785806 (diff)
downloadrails-d4cd7e2a44b2c19df31f7cb0ce03b957f3a359af.tar.gz
rails-d4cd7e2a44b2c19df31f7cb0ce03b957f3a359af.tar.bz2
rails-d4cd7e2a44b2c19df31f7cb0ce03b957f3a359af.zip
Revert some stuff to use the new sanitizers.
Diffstat (limited to 'actionview/lib')
-rw-r--r--actionview/lib/action_view/helpers/sanitize_helper.rb12
1 files changed, 6 insertions, 6 deletions
diff --git a/actionview/lib/action_view/helpers/sanitize_helper.rb b/actionview/lib/action_view/helpers/sanitize_helper.rb
index f205a988b4..6c1be1ef4e 100644
--- a/actionview/lib/action_view/helpers/sanitize_helper.rb
+++ b/actionview/lib/action_view/helpers/sanitize_helper.rb
@@ -138,16 +138,16 @@ module ActionView
end
# A class to vendor out the full, link and white list sanitizers
# Can be set to either HTML::Scanner or HTML::Sanitizer
mattr_accessor :sanitizer_vendor
- self.sanitizer_vendor = HTML::Scanner
+ self.sanitizer_vendor = Rails::Html::Sanitizer
def sanitized_allowed_tags
- HTML::WhiteListSanitizer.allowed_tags
+ Rails::Html::WhiteListSanitizer.allowed_tags
end
def sanitized_allowed_attributes
- HTML::WhiteListSanitizer.allowed_attributes
+ Rails::Html::WhiteListSanitizer.allowed_attributes
end
# Gets the Rails::Html::FullSanitizer instance used by +strip_tags+. Replace with
@@ -190,7 +190,7 @@ module ActionView
# end
#
def sanitized_allowed_tags=(*tags)
- HTML::WhiteListSanitizer.allowed_tags = tags
+ Rails::Html::WhiteListSanitizer.allowed_tags = tags
end
# Replaces the allowed HTML attributes for the +sanitize+ helper.
@@ -200,7 +200,7 @@ module ActionView
# end
#
def sanitized_allowed_attributes=(*attributes)
- HTML::WhiteListSanitizer.allowed_attributes = attributes
+ Rails::Html::WhiteListSanitizer.allowed_attributes = attributes
end
end
end
@@ -138,16 +138,16 @@ module ActionView
end
# A class to vendor out the full, link and white list sanitizers
- # Can be set to either HTML::Scanner or HTML::Sanitizer
+ # Can be set to either HTML::Deprecated::Sanitizer or Rails::Html::Sanitizer
mattr_accessor :sanitizer_vendor